"""
framelib module
"""

from .frame import render_frame, message
from .models import FrameMessage, ValidatedMessage, User
from .warpcast import get_user
from .neynar import validate_message, validate_message_or_mock, validate_message_or_mock_vercel



"""
data models
"""

from typing import Optional
from pydantic import BaseModel


# ---- frame message ----

class CastId(BaseModel):
    fid: int
    hash: str


class UntrustedData(BaseModel):
    fid: int
    url: str
    messageHash: str
    timestamp: int
    network: int
    buttonIndex: int
    inputText: Optional[str] = None
    castId: CastId


class TrustedData(BaseModel):
    messageBytes: str


class FrameMessage(BaseModel):
    untrustedData: UntrustedData
    trustedData: TrustedData


# ---- neynar ----

class Viewer(BaseModel):
    following: bool
    followed_by: bool


class Bio(BaseModel):
    text: str
    mentioned_profiles: Optional[list[str]] = []


class Profile(BaseModel):
    bio: Bio


class Interactor(BaseModel):
    object: str
    fid: int
    username: str
    display_name: str
    custody_address: Optional[str] = None
    pfp_url: str
    profile: Profile
    follower_count: int
    following_count: int
    verifications: list[str]
    active_status: str
    viewer_context: Optional[Viewer] = None


class Button(BaseModel):
    title: Optional[str] = None
    index: int
    action_type: Optional[str] = None


class Input(BaseModel):
    text: str


class ValidatedMessage(BaseModel):
    object: str
    interactor: Interactor
    tapped_button: Button
    input: Input
    url: str
    cast: dict


# ---- warpcast ----

class Pfp(BaseModel):
    url: str
    verified: bool


class WarpBio(BaseModel):
    text: str
    mentions: Optional[list[str]] = []
    channelMentions: Optional[list[str]] = []


class WarpLocation(BaseModel):
    placeId: str
    description: str


class WarpProfile(BaseModel):
    bio: WarpBio
    location: WarpLocation


class User(BaseModel):
    fid: int
    username: Optional[str] = None
    displayName: str
    pfp: Optional[Pfp] = None
    profile: WarpProfile
    followerCount: int
    followingCount: int
    activeOnFcNetwork: bool



"""
test cases for frame rendering
"""

# lib
import time
import pytest
from flask import Flask

# src
from framelib import render_frame

app = Flask(__name__)


class TestRenderFrame(object):

    def test_one_button(self):
        with app.app_context():
            r = render_frame(button1='click')
            assert r.status_code == 200
            assert b'<meta property="fc:frame:button:1" content="click"/>' in r.data
            assert b'<meta property="fc:frame:button:2"' not in r.data

    def test_multiple_buttons(self):
        with app.app_context():
            r = render_frame(image='https://website.com/im.png', button1='click', button2='other', button3='back')
            assert r.status_code == 200
            assert b'<meta property="fc:frame:button:1" content="click"/>' in r.data
            assert b'<meta property="fc:frame:button:2" content="other"/>' in r.data
            assert b'<meta property="fc:frame:button:3" content="back"/>' in r.data
            assert b'<meta property="fc:frame:button:4"' not in r.data
            assert b'<meta property="fc:frame:image" content="https://website.com/im.png"/>' in r.data



import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='framelib',
    version='0.0.1',
    author='Devin A. Conley',
    author_email='devinaconley@gmail.com',
    description='lightweight library for building farcaster frames using python and flask',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/devinaconley/python-frames',
    packages=setuptools.find_packages(),
    package_data={
        'framelib': ['templates/*.html']
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    install_requires=[
        'flask>=3,<4',
        'pydantic>=2,<3',
        'requests>=2,<3'
    ]
)
